CREATE TABLE ADR.ADRES_LOG
(
  LOGTARIHI         DATE,
  ISLEM             CHAR(1 BYTE),
  ADRESNO           INTEGER                     NOT NULL,
  KURUMNO           INTEGER,
  ADRESTIPIKODU     INTEGER                     NOT NULL,
  KISINO            INTEGER,
  ADRESSATIRI1      VARCHAR2(50)           NOT NULL,
  ADRESSATIRI2      VARCHAR2(50),
  POSTAKODU         VARCHAR2(5),
  SEMT              VARCHAR2(50),
  ILKODU            INTEGER                     NOT NULL,
  ILCEKODU          INTEGER                     NOT NULL,
  ULKEKODU          INTEGER                     NOT NULL,
  YAZISMAADRESI     CHAR(1)                NOT NULL,
  GECERSIZ          CHAR(1),
  OLUSTURMATARIHI   DATE,
  DEGISTIRMETARIHI  DATE,
  KULLANICI         VARCHAR2(30)
)
LOGGING 
NOCACHE
NOPARALLEL
NOMONITORING;


CREATE TABLE ADR.KURUMFAALIYETDETAY_LOG
(
  LOGTARIHI         DATE,
  ISLEM             CHAR(1),
  KURUMNO           INTEGER                     NOT NULL,
  FAALIYETTIPKODU   INTEGER                     NOT NULL,
  FAALIYETDETAY     VARCHAR2(2000),
  OLUSTURMATARIHI   DATE,
  DEGISTIRMETARIHI  DATE,
  KULLANICI         VARCHAR2(30)
)
LOGGING 
NOCACHE
NOPARALLEL
NOMONITORING;


CREATE TABLE ADR.TELEFON_LOG
(
  LOGTARIHI         DATE,
  ISLEM             CHAR(1),
  TELEFONSIRANO     INTEGER                     NOT NULL,
  KURUMNO           INTEGER,
  KISINO            INTEGER,
  TELEFONTIPIKODU   INTEGER                     NOT NULL,
  ULKETELEFONKODU   VARCHAR2(5),
  NUMARA            VARCHAR2(10)           NOT NULL,
  ACIKLAMA          VARCHAR2(100),
  OLUSTURMATARIHI   DATE,
  DEGISTIRMETARIHI  DATE,
  KULLANICI         VARCHAR2(30)
)
LOGGING 
NOCACHE
NOPARALLEL
NOMONITORING;


CREATE UNIQUE INDEX ADR.PK_ADRES_LOG ON ADR.ADRES_LOG
(LOGTARIHI, ISLEM, ADRESNO)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX ADR.PK_KURUMFAALIYETDETAY_LOG ON ADR.KURUMFAALIYETDETAY_LOG
(LOGTARIHI, ISLEM, KURUMNO, FAALIYETTIPKODU)
LOGGING
NOPARALLEL;


CREATE UNIQUE INDEX ADR.PK_TELEFON_LOG ON ADR.TELEFON_LOG
(LOGTARIHI, ISLEM, TELEFONSIRANO)
LOGGING
NOPARALLEL;


ALTER TABLE ADR.ADRES_LOG ADD (
  CONSTRAINT PK_ADRES_LOG
 PRIMARY KEY
 (LOGTARIHI, ISLEM, ADRESNO)
    USING INDEX 
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       UNLIMITED
                PCTINCREASE      0
               ));

ALTER TABLE ADR.KURUMFAALIYETDETAY_LOG ADD (
  CONSTRAINT PK_KURUMFAALIYETDETAY_LOG
 PRIMARY KEY
 (LOGTARIHI, ISLEM, KURUMNO, FAALIYETTIPKODU)
    USING INDEX 
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       UNLIMITED
                PCTINCREASE      0
               ));


ALTER TABLE ADR.TELEFON_LOG ADD (
  CONSTRAINT PK_TELEFON_LOG
 PRIMARY KEY
 (LOGTARIHI, ISLEM, TELEFONSIRANO)
    USING INDEX 
    PCTFREE    10
    INITRANS   2
    MAXTRANS   255
    STORAGE    (
                INITIAL          64K
                MINEXTENTS       1
                MAXEXTENTS       UNLIMITED
                PCTINCREASE      0
               ));



CREATE OR REPLACE TRIGGER ADR.AU_TELEFON_LOG
AFTER UPDATE
ON ADR.TELEFON REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AU_TELEFON_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AU_TELEFON_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      TELEFON (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.TELEFON_LOG (
        LOGTARIHI, ISLEM, TELEFONSIRANO, 
        KURUMNO, KISINO, TELEFONTIPIKODU, 
        ULKETELEFONKODU, NUMARA, ACIKLAMA, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'U' , :old.TELEFONSIRANO ,
        :old.KURUMNO, :old.KISINO, :old.TELEFONTIPIKODU, 
        :old.ULKETELEFONKODU, :old.NUMARA, :old.ACIKLAMA, 
        :old.OLUSTURMATARIHI, :old.DEGISTIRMETARIHI, ls_kullaniciadi );

End;
/


CREATE OR REPLACE TRIGGER ADR.AU_KURUMFAALIYETDETAY_LOG
AFTER UPDATE
ON ADR.KURUMFAALIYETDETAY 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AU_KURUMFAALIYETDETAY_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AU_KURUMFAALIYETDETAY_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      KURUMFAALIYETDETAY(set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.KURUMFAALIYETDETAY_LOG (
        LOGTARIHI, ISLEM, KURUMNO, 
        FAALIYETTIPKODU, FAALIYETDETAY, OLUSTURMATARIHI, 
        DEGISTIRMETARIHI, KULLANICI) 

     VALUES (sysdate ,'U' , :old.KURUMNO, 
        :old.FAALIYETTIPKODU, :old.FAALIYETDETAY, :old.OLUSTURMATARIHI, 
        :old.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AU_ADRES_LOG
AFTER UPDATE
ON ADR.ADRES 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AU_ADRES_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AU_ADRES_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      ADRES (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.ADRES_LOG (
        LOGTARIHI, ISLEM, ADRESNO, 
        KURUMNO, ADRESTIPIKODU, KISINO, 
        ADRESSATIRI1, ADRESSATIRI2, POSTAKODU, 
        SEMT, ILKODU, ILCEKODU, 
        ULKEKODU, YAZISMAADRESI, GECERSIZ, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'U' , :old.ADRESNO ,
        :old.KURUMNO, :old.ADRESTIPIKODU, :old.KISINO, 
        :old.ADRESSATIRI1, :old.ADRESSATIRI2, :old.POSTAKODU, 
        :old.SEMT, :old.ILKODU, :old.ILCEKODU, 
        :old.ULKEKODU, :old.YAZISMAADRESI, :old.GECERSIZ, 
        :old.OLUSTURMATARIHI, :old.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AI_TELEFON_LOG
AFTER INSERT
ON ADR.TELEFON REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AI_TELEFON_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AI_TELEFON_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      TELEFON (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.TELEFON_LOG (
        LOGTARIHI, ISLEM, TELEFONSIRANO, 
        KURUMNO, KISINO, TELEFONTIPIKODU, 
        ULKETELEFONKODU, NUMARA, ACIKLAMA, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'I' , :new.TELEFONSIRANO ,
        :new.KURUMNO, :new.KISINO, :new.TELEFONTIPIKODU, 
        :new.ULKETELEFONKODU, :new.NUMARA, :new.ACIKLAMA, 
        :new.OLUSTURMATARIHI, :new.DEGISTIRMETARIHI, ls_kullaniciadi );

End;
/


CREATE OR REPLACE TRIGGER ADR.AI_KURUMFAALIYETDETAY_LOG
AFTER INSERT
ON ADR.KURUMFAALIYETDETAY 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AI_KURUMFAALIYETDETAY_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AI_KURUMFAALIYETDETAY_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      KURUMFAALIYETDETAY(set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.KURUMFAALIYETDETAY_LOG (
        LOGTARIHI, ISLEM, KURUMNO, 
        FAALIYETTIPKODU, FAALIYETDETAY, OLUSTURMATARIHI, 
        DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'I' , :new.KURUMNO, 
        :new.FAALIYETTIPKODU, :new.FAALIYETDETAY, :new.OLUSTURMATARIHI, 
        :new.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AI_ADRES_LOG
AFTER INSERT
ON ADR.ADRES 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AI_ADRES_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AI_ADRES_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      ADRES (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.ADRES_LOG (
        LOGTARIHI, ISLEM, ADRESNO, 
        KURUMNO, ADRESTIPIKODU, KISINO, 
        ADRESSATIRI1, ADRESSATIRI2, POSTAKODU, 
        SEMT, ILKODU, ILCEKODU, 
        ULKEKODU, YAZISMAADRESI, GECERSIZ, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'I' , :new.ADRESNO ,
        :new.KURUMNO, :new.ADRESTIPIKODU, :new.KISINO, 
        :new.ADRESSATIRI1, :new.ADRESSATIRI2, :new.POSTAKODU, 
        :new.SEMT, :new.ILKODU, :new.ILCEKODU, 
        :new.ULKEKODU, :new.YAZISMAADRESI, :new.GECERSIZ, 
        :new.OLUSTURMATARIHI, :new.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AD_TELEFON_LOG
AFTER DELETE
ON ADR.TELEFON REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AD_TELEFON_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AD_TELEFON_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      TELEFON (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.TELEFON_LOG (
        LOGTARIHI, ISLEM, TELEFONSIRANO, 
        KURUMNO, KISINO, TELEFONTIPIKODU, 
        ULKETELEFONKODU, NUMARA, ACIKLAMA, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'D' , :old.TELEFONSIRANO ,
        :old.KURUMNO, :old.KISINO, :old.TELEFONTIPIKODU, 
        :old.ULKETELEFONKODU, :old.NUMARA, :old.ACIKLAMA, 
        :old.OLUSTURMATARIHI, :old.DEGISTIRMETARIHI, ls_kullaniciadi );
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AD_KURUMFAALIYETDETAY_LOG
AFTER DELETE
ON ADR.KURUMFAALIYETDETAY 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AD_KURUMFAALIYETDETAY_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AD_KURUMFAALIYETDETAY_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      KURUMFAALIYETDETAY(set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.KURUMFAALIYETDETAY_LOG (
        LOGTARIHI, ISLEM, KURUMNO, 
        FAALIYETTIPKODU, FAALIYETDETAY, OLUSTURMATARIHI, 
        DEGISTIRMETARIHI, KULLANICI) 

     VALUES (sysdate ,'D' , :old.KURUMNO, 
        :old.FAALIYETTIPKODU, :old.FAALIYETDETAY, :old.OLUSTURMATARIHI, 
        :old.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/


CREATE OR REPLACE TRIGGER ADR.AD_ADRES_LOG
AFTER DELETE
ON ADR.ADRES 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
DECLARE

/******************************************************************************
   NAME:       AD_ADRES_LOG
   PURPOSE:    

   REVISIONS:
   Ver        Date        Author           Description
   ---------  ----------  ---------------  ------------------------------------
   1.0        14.06.2011  Gktan Elgin     1. Created this trigger.

   NOTES:

   Automatically available Auto Replace Keywords:
      Object Name:     AD_ADRES_LOG
      Sysdate:         14.06.2011
      Date and Time:   14.06.2011, 15:11:30, and 14.06.2011 15:11:30
      Table Name:      ADRES (set in the "New PL/SQL Object" dialog)
******************************************************************************/

ls_kullaniciadi varchar2(30);

Begin

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

 
     INSERT INTO ADR.ADRES_LOG (
        LOGTARIHI, ISLEM, ADRESNO, 
        KURUMNO, ADRESTIPIKODU, KISINO, 
        ADRESSATIRI1, ADRESSATIRI2, POSTAKODU, 
        SEMT, ILKODU, ILCEKODU, 
        ULKEKODU, YAZISMAADRESI, GECERSIZ, 
        OLUSTURMATARIHI, DEGISTIRMETARIHI, KULLANICI) 
     VALUES (sysdate ,'D' , :old.ADRESNO ,
        :old.KURUMNO, :old.ADRESTIPIKODU, :old.KISINO, 
        :old.ADRESSATIRI1, :old.ADRESSATIRI2, :old.POSTAKODU, 
        :old.SEMT, :old.ILKODU, :old.ILCEKODU, 
        :old.ULKEKODU, :old.YAZISMAADRESI, :old.GECERSIZ, 
        :old.OLUSTURMATARIHI, :old.DEGISTIRMETARIHI, ls_kullaniciadi);
  

End;
/
--* KURUM_LOG EK

ALTER TABLE ADR.KURUM_LOG
ADD (ISLEM CHAR(1));

UPDATE ADR.KURUM_LOG SET ISLEM = 'U';

COMMIT;

CREATE OR REPLACE TRIGGER ADR.AU_KURUM_KURUMLOG
AFTER UPDATE
ON ADR.KURUM 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Declare
    ldt_GunlemeTarihi  DATE;
    ls_kullaniciadi varchar2(30);
Begin

    -- --------------------------------------------------------------------------- --
    -- Programmers  : Rifat YILMAZ                                                 --
    -- GE: KullaniciAdi , slem Eklendi 20.06.2011
    -- Description  : Adr.KURUM tablosundaki kayitlarda yapilan degisiklikleri     --
    --    Adr.Kurum_Log tablosuna kaydetmektedir. Bylece kurum bilgilerini logu   --
    --    tutulmaktadir.                                                               --
    -- --------------------------------------------------------------------------- --

    ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

    SELECT SysDate INTO ldt_GunlemeTarihi  FROM DUAL;

    Insert into Adr.Kurum_Log (  KurumNo                ,
                                LogTarihi               ,
                                KurumTipKodu            ,
                                UstKurumNo              ,
                                KurumUnvani             ,
                                KisaAd                  ,
                                TicariEsnafSicilNo      ,
                                TicaretEsnafSicilAyirimi,
                                KurulusTarihi           ,
                                OdaTescilTarihi         ,
                                OdaSicilNo              ,
                                VergiNumarasi           ,
                                VergiDairesi            ,
                                EpostaAdresi            ,
                                WebAdresi               ,
                                EpostaAdresi2           ,
                                Sermayesi               ,
                                Aciklama                ,
                                TSMBolgesiKodu          ,
                                OdaBolgeKodu            ,
                                Merkez_Sube             ,
                                IsciSayisi              ,
                                YabanciSermaye          ,
                                Ozvarlik                ,
                                KullaniciAdi            ,
                                Islem
                            )
                    Values
                            (   :Old.KurumNo                 ,
                                ldt_GunlemeTarihi            ,
                                :Old.KurumTipKodu            ,
                                :Old.UstKurumNo              ,
                                :Old.KurumUnvani             ,
                                :Old.KisaAd                  ,
                                :Old.TicariEsnafSicilNo      ,
                                :Old.TicaretEsnafSicilAyirimi,
                                :Old.KurulusTarihi           ,
                                :Old.OdaTescilTarihi         ,
                                :Old.OdaSicilNo              ,
                                :Old.VergiNumarasi           ,
                                :Old.VergiDairesi            ,
                                :Old.EpostaAdresi            ,
                                :Old.WebAdresi               ,
                                :Old.EpostaAdresi2           ,
                                :Old.Sermayesi               ,
                                :Old.Aciklama                 ,
                                :Old.TSMBolgesiKodu             ,
                                :Old.OdaBolgeKodu             ,
                                :Old.Merkez_Sube             ,
                                :Old.IsciSayisi                 ,
                                :Old.YabanciSermaye             ,
                                :Old.Ozvarlik                ,
                                ls_kullaniciadi             ,
                                'U'
                            );
End;
/

CREATE OR REPLACE TRIGGER ADR.AD_KURUM_KURUMLOG
AFTER DELETE
ON ADR.KURUM 
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
Declare
    ldt_GunlemeTarihi  DATE;
    ls_kullaniciadi varchar2(30);
Begin

    -- --------------------------------------------------------------------------- --
    -- Programmers  : Gktan ELGN                                                --
    -- Description  : Adr.KURUM tablosundaki kayitlarda yapilan degisiklikleri     --
    --    Adr.Kurum_Log tablosuna kaydetmektedir. Bylece kurum bilgilerini logu   --
    --    tutulmaktadir.                                                               --
    -- --------------------------------------------------------------------------- --

    ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;

    SELECT SysDate INTO ldt_GunlemeTarihi  FROM DUAL;

    Insert into Adr.Kurum_Log (  KurumNo                ,
                                LogTarihi               ,
                                KurumTipKodu            ,
                                UstKurumNo              ,
                                KurumUnvani             ,
                                KisaAd                  ,
                                TicariEsnafSicilNo      ,
                                TicaretEsnafSicilAyirimi,
                                KurulusTarihi           ,
                                OdaTescilTarihi         ,
                                OdaSicilNo              ,
                                VergiNumarasi           ,
                                VergiDairesi            ,
                                EpostaAdresi            ,
                                WebAdresi               ,
                                EpostaAdresi2           ,
                                Sermayesi               ,
                                Aciklama                ,
                                TSMBolgesiKodu          ,
                                OdaBolgeKodu            ,
                                Merkez_Sube             ,
                                IsciSayisi              ,
                                YabanciSermaye          ,
                                Ozvarlik                ,
                                KullaniciAdi            ,
                                Islem
                            )
                    Values
                            (   :Old.KurumNo                 ,
                                ldt_GunlemeTarihi            ,
                                :Old.KurumTipKodu            ,
                                :Old.UstKurumNo              ,
                                :Old.KurumUnvani             ,
                                :Old.KisaAd                  ,
                                :Old.TicariEsnafSicilNo      ,
                                :Old.TicaretEsnafSicilAyirimi,
                                :Old.KurulusTarihi           ,
                                :Old.OdaTescilTarihi         ,
                                :Old.OdaSicilNo              ,
                                :Old.VergiNumarasi           ,
                                :Old.VergiDairesi            ,
                                :Old.EpostaAdresi            ,
                                :Old.WebAdresi               ,
                                :Old.EpostaAdresi2           ,
                                :Old.Sermayesi               ,
                                :Old.Aciklama                 ,
                                :Old.TSMBolgesiKodu             ,
                                :Old.OdaBolgeKodu             ,
                                :Old.Merkez_Sube             ,
                                :Old.IsciSayisi                 ,
                                :Old.YabanciSermaye             ,
                                :Old.Ozvarlik                ,
                                ls_kullaniciadi             ,
                                'D'
                            );
End;
/


